'use strict';

var path = require('path');
var spawn = require('cross-spawn');
var yargsParser = require('yargs-parser');

var _require = require('../utils'),
    hasPkgProp = _require.hasPkgProp,
    resolveBin = _require.resolveBin,
    hasFile = _require.hasFile;

var args = process.argv.slice(2);
var parsedArgs = yargsParser(args);

var here = function (p) {
  return path.join(__dirname, p);
};

var useBuiltinConfig = !args.includes('--config') && !hasFile('.prettierrc') && !hasPkgProp('prettierrc');
var config = useBuiltinConfig ? ['--config', here('../config/prettierrc.js')] : [];

var useBuiltinIgnore = !args.includes('--ignore-path') && !hasFile('.prettierignore');
var ignore = useBuiltinIgnore ? ['--ignore-path', here('../config/prettierignore')] : [];

var write = args.includes('--no-write') ? [] : ['--write'];

// this ensures that when running format as a pre-commit hook and we get
// the full file path, we make that non-absolute so it is treated as a glob,
// This way the prettierignore will be applied
var relativeArgs = args.map(function (a) {
  return a.replace(`${process.cwd()}/`, '');
});

var filesToApply = parsedArgs._.length ? [] : ['**/*.js'];

var result = spawn.sync(resolveBin('prettier'), [].concat(config, ignore, write, filesToApply).concat(relativeArgs), { stdio: 'inherit' });

process.exit(result.status);